pub struct PlinkoAxisTranche {
pub attribute_id: AttributeId,
pub cap_micro: i64,
pub scale_micro: i64,
}Expand description
Транш одной оси на одном уровне сундука: до какого суммарного значения он доводит ось и по сколько прибавляет одно касание.
Потолки монотонно растут по уровню сундука, поэтому «сколько ещё можно
набрать» — это cap_micro первого незаполненного транша, а не отдельная
валюта: история касаний не нужна.
Fields
attribute_id: AttributeIdcap_micro: i64scale_micro: i64Trait Implementations
Sourceimpl Clone for PlinkoAxisTranche
impl Clone for PlinkoAxisTranche
Sourcefn clone(&self) -> PlinkoAxisTranche
fn clone(&self) -> PlinkoAxisTranche
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlinkoAxisTranche
impl Debug for PlinkoAxisTranche
Sourceimpl<'de> Deserialize<'de> for PlinkoAxisTranche
impl<'de> Deserialize<'de> for PlinkoAxisTranche
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlinkoAxisTranche
impl JsonSchema for PlinkoAxisTranche
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for PlinkoAxisTranche
impl Serialize for PlinkoAxisTranche
Sourceimpl Tsify for PlinkoAxisTranche
impl Tsify for PlinkoAxisTranche
const DECL: &'static str = "/**\n * \u{422}\u{440}\u{430}\u{43d}\u{448} \u{43e}\u{434}\u{43d}\u{43e}\u{439} \u{43e}\u{441}\u{438} \u{43d}\u{430} \u{43e}\u{434}\u{43d}\u{43e}\u{43c} \u{443}\u{440}\u{43e}\u{432}\u{43d}\u{435} \u{441}\u{443}\u{43d}\u{434}\u{443}\u{43a}\u{430}: \u{434}\u{43e} \u{43a}\u{430}\u{43a}\u{43e}\u{433}\u{43e} \u{441}\u{443}\u{43c}\u{43c}\u{430}\u{440}\u{43d}\u{43e}\u{433}\u{43e} \u{437}\u{43d}\u{430}\u{447}\u{435}\u{43d}\u{438}\u{44f} \u{43e}\u{43d}\n * \u{434}\u{43e}\u{432}\u{43e}\u{434}\u{438}\u{442} \u{43e}\u{441}\u{44c} \u{438} \u{43f}\u{43e} \u{441}\u{43a}\u{43e}\u{43b}\u{44c}\u{43a}\u{43e} \u{43f}\u{440}\u{438}\u{431}\u{430}\u{432}\u{43b}\u{44f}\u{435}\u{442} \u{43e}\u{434}\u{43d}\u{43e} \u{43a}\u{430}\u{441}\u{430}\u{43d}\u{438}\u{435}.\n *\n * \u{41f}\u{43e}\u{442}\u{43e}\u{43b}\u{43a}\u{438} \u{43c}\u{43e}\u{43d}\u{43e}\u{442}\u{43e}\u{43d}\u{43d}\u{43e} \u{440}\u{430}\u{441}\u{442}\u{443}\u{442} \u{43f}\u{43e} \u{443}\u{440}\u{43e}\u{432}\u{43d}\u{44e} \u{441}\u{443}\u{43d}\u{434}\u{443}\u{43a}\u{430}, \u{43f}\u{43e}\u{44d}\u{442}\u{43e}\u{43c}\u{443} \u{ab}\u{441}\u{43a}\u{43e}\u{43b}\u{44c}\u{43a}\u{43e} \u{435}\u{449}\u{451} \u{43c}\u{43e}\u{436}\u{43d}\u{43e}\n * \u{43d}\u{430}\u{431}\u{440}\u{430}\u{442}\u{44c}\u{bb} \u{2014} \u{44d}\u{442}\u{43e} `cap_micro` \u{43f}\u{435}\u{440}\u{432}\u{43e}\u{433}\u{43e} \u{43d}\u{435}\u{437}\u{430}\u{43f}\u{43e}\u{43b}\u{43d}\u{435}\u{43d}\u{43d}\u{43e}\u{433}\u{43e} \u{442}\u{440}\u{430}\u{43d}\u{448}\u{430}, \u{430} \u{43d}\u{435} \u{43e}\u{442}\u{434}\u{435}\u{43b}\u{44c}\u{43d}\u{430}\u{44f}\n * \u{432}\u{430}\u{43b}\u{44e}\u{442}\u{430}: \u{438}\u{441}\u{442}\u{43e}\u{440}\u{438}\u{44f} \u{43a}\u{430}\u{441}\u{430}\u{43d}\u{438}\u{439} \u{43d}\u{435} \u{43d}\u{443}\u{436}\u{43d}\u{430}.\n */\nexport interface PlinkoAxisTranche {\n attribute_id: AttributeId;\n cap_micro: number;\n scale_micro: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Copy for PlinkoAxisTranche