pub struct PlinkoPinBonus {
pub row: i64,
pub column: i64,
pub attribute_id: AttributeId,
pub value: i64,
}Expand description
Постоянная прибавка к стату за касание конкретного колышка.
Один колышек доски: какой оси он принадлежит и каков его БЕЗРАЗМЕРНЫЙ вес.
Сам по себе вес ничего не начисляет — прибавка за касание считается как
вес × scale текущего транша (BAL-021), поэтому один и тот же колышек
стоит по-разному на разных уровнях сундука.
Fields
row: i64column: i64attribute_id: AttributeIdvalue: i64Trait Implementations
Sourceimpl Clone for PlinkoPinBonus
impl Clone for PlinkoPinBonus
Sourcefn clone(&self) -> PlinkoPinBonus
fn clone(&self) -> PlinkoPinBonus
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlinkoPinBonus
impl Debug for PlinkoPinBonus
Sourceimpl<'de> Deserialize<'de> for PlinkoPinBonus
impl<'de> Deserialize<'de> for PlinkoPinBonus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlinkoPinBonus
impl JsonSchema for PlinkoPinBonus
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for PlinkoPinBonus
impl Serialize for PlinkoPinBonus
Sourceimpl Tsify for PlinkoPinBonus
impl Tsify for PlinkoPinBonus
const DECL: &'static str = "/**\n * \u{41f}\u{43e}\u{441}\u{442}\u{43e}\u{44f}\u{43d}\u{43d}\u{430}\u{44f} \u{43f}\u{440}\u{438}\u{431}\u{430}\u{432}\u{43a}\u{430} \u{43a} \u{441}\u{442}\u{430}\u{442}\u{443} \u{437}\u{430} \u{43a}\u{430}\u{441}\u{430}\u{43d}\u{438}\u{435} \u{43a}\u{43e}\u{43d}\u{43a}\u{440}\u{435}\u{442}\u{43d}\u{43e}\u{433}\u{43e} \u{43a}\u{43e}\u{43b}\u{44b}\u{448}\u{43a}\u{430}.\n *\n * \u{41e}\u{434}\u{438}\u{43d} \u{43a}\u{43e}\u{43b}\u{44b}\u{448}\u{435}\u{43a} \u{434}\u{43e}\u{441}\u{43a}\u{438}: \u{43a}\u{430}\u{43a}\u{43e}\u{439} \u{43e}\u{441}\u{438} \u{43e}\u{43d} \u{43f}\u{440}\u{438}\u{43d}\u{430}\u{434}\u{43b}\u{435}\u{436}\u{438}\u{442} \u{438} \u{43a}\u{430}\u{43a}\u{43e}\u{432} \u{435}\u{433}\u{43e} \u{411}\u{415}\u{417}\u{420}\u{410}\u{417}\u{41c}\u{415}\u{420}\u{41d}\u{42b}\u{419} \u{432}\u{435}\u{441}.\n *\n * \u{421}\u{430}\u{43c} \u{43f}\u{43e} \u{441}\u{435}\u{431}\u{435} \u{432}\u{435}\u{441} \u{43d}\u{438}\u{447}\u{435}\u{433}\u{43e} \u{43d}\u{435} \u{43d}\u{430}\u{447}\u{438}\u{441}\u{43b}\u{44f}\u{435}\u{442} \u{2014} \u{43f}\u{440}\u{438}\u{431}\u{430}\u{432}\u{43a}\u{430} \u{437}\u{430} \u{43a}\u{430}\u{441}\u{430}\u{43d}\u{438}\u{435} \u{441}\u{447}\u{438}\u{442}\u{430}\u{435}\u{442}\u{441}\u{44f} \u{43a}\u{430}\u{43a}\n * `\u{432}\u{435}\u{441} \u{d7} scale \u{442}\u{435}\u{43a}\u{443}\u{449}\u{435}\u{433}\u{43e} \u{442}\u{440}\u{430}\u{43d}\u{448}\u{430}` (BAL-021), \u{43f}\u{43e}\u{44d}\u{442}\u{43e}\u{43c}\u{443} \u{43e}\u{434}\u{438}\u{43d} \u{438} \u{442}\u{43e}\u{442} \u{436}\u{435} \u{43a}\u{43e}\u{43b}\u{44b}\u{448}\u{435}\u{43a}\n * \u{441}\u{442}\u{43e}\u{438}\u{442} \u{43f}\u{43e}-\u{440}\u{430}\u{437}\u{43d}\u{43e}\u{43c}\u{443} \u{43d}\u{430} \u{440}\u{430}\u{437}\u{43d}\u{44b}\u{445} \u{443}\u{440}\u{43e}\u{432}\u{43d}\u{44f}\u{445} \u{441}\u{443}\u{43d}\u{434}\u{443}\u{43a}\u{430}.\n */\nexport interface PlinkoPinBonus {\n row: number;\n column: number;\n attribute_id: AttributeId;\n value: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>