pub struct PlinkoSlotGroup {
pub from_slot: i64,
pub to_slot: i64,
pub rarity_id: ItemRarityId,
pub is_locked: bool,
}Expand description
Группа физических слотов доски, подписанная одной редкостью.
Физические слоты нумеруются 0..=rows; группы одного уровня должны
покрывать этот диапазон без дыр и пересечений. Если у редкости несколько
физических слотов (from_slot != to_slot), сервер сам выбирает, в какой
из них уронить шарик.
Fields
from_slot: i64to_slot: i64rarity_id: ItemRarityIdis_locked: boolTrait Implementations
Sourceimpl Clone for PlinkoSlotGroup
impl Clone for PlinkoSlotGroup
Sourcefn clone(&self) -> PlinkoSlotGroup
fn clone(&self) -> PlinkoSlotGroup
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlinkoSlotGroup
impl Debug for PlinkoSlotGroup
Sourceimpl<'de> Deserialize<'de> for PlinkoSlotGroup
impl<'de> Deserialize<'de> for PlinkoSlotGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlinkoSlotGroup
impl JsonSchema for PlinkoSlotGroup
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for PlinkoSlotGroup
impl Serialize for PlinkoSlotGroup
Sourceimpl Tsify for PlinkoSlotGroup
impl Tsify for PlinkoSlotGroup
const DECL: &'static str = "/**\n * \u{413}\u{440}\u{443}\u{43f}\u{43f}\u{430} \u{444}\u{438}\u{437}\u{438}\u{447}\u{435}\u{441}\u{43a}\u{438}\u{445} \u{441}\u{43b}\u{43e}\u{442}\u{43e}\u{432} \u{434}\u{43e}\u{441}\u{43a}\u{438}, \u{43f}\u{43e}\u{434}\u{43f}\u{438}\u{441}\u{430}\u{43d}\u{43d}\u{430}\u{44f} \u{43e}\u{434}\u{43d}\u{43e}\u{439} \u{440}\u{435}\u{434}\u{43a}\u{43e}\u{441}\u{442}\u{44c}\u{44e}.\n * \u{424}\u{438}\u{437}\u{438}\u{447}\u{435}\u{441}\u{43a}\u{438}\u{435} \u{441}\u{43b}\u{43e}\u{442}\u{44b} \u{43d}\u{443}\u{43c}\u{435}\u{440}\u{443}\u{44e}\u{442}\u{441}\u{44f} `0..=rows`; \u{433}\u{440}\u{443}\u{43f}\u{43f}\u{44b} \u{43e}\u{434}\u{43d}\u{43e}\u{433}\u{43e} \u{443}\u{440}\u{43e}\u{432}\u{43d}\u{44f} \u{434}\u{43e}\u{43b}\u{436}\u{43d}\u{44b}\n * \u{43f}\u{43e}\u{43a}\u{440}\u{44b}\u{432}\u{430}\u{442}\u{44c} \u{44d}\u{442}\u{43e}\u{442} \u{434}\u{438}\u{430}\u{43f}\u{430}\u{437}\u{43e}\u{43d} \u{431}\u{435}\u{437} \u{434}\u{44b}\u{440} \u{438} \u{43f}\u{435}\u{440}\u{435}\u{441}\u{435}\u{447}\u{435}\u{43d}\u{438}\u{439}. \u{415}\u{441}\u{43b}\u{438} \u{443} \u{440}\u{435}\u{434}\u{43a}\u{43e}\u{441}\u{442}\u{438} \u{43d}\u{435}\u{441}\u{43a}\u{43e}\u{43b}\u{44c}\u{43a}\u{43e}\n * \u{444}\u{438}\u{437}\u{438}\u{447}\u{435}\u{441}\u{43a}\u{438}\u{445} \u{441}\u{43b}\u{43e}\u{442}\u{43e}\u{432} (`from_slot != to_slot`), \u{441}\u{435}\u{440}\u{432}\u{435}\u{440} \u{441}\u{430}\u{43c} \u{432}\u{44b}\u{431}\u{438}\u{440}\u{430}\u{435}\u{442}, \u{432} \u{43a}\u{430}\u{43a}\u{43e}\u{439}\n * \u{438}\u{437} \u{43d}\u{438}\u{445} \u{443}\u{440}\u{43e}\u{43d}\u{438}\u{442}\u{44c} \u{448}\u{430}\u{440}\u{438}\u{43a}.\n */\nexport interface PlinkoSlotGroup {\n from_slot: number;\n to_slot: number;\n rarity_id: ItemRarityId;\n is_locked: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>