pub struct PlinkoTranche {
pub chest_level: i64,
pub axes: Vec<PlinkoAxisTranche>,
}Expand description
Все оси одного уровня сундука.
Fields
chest_level: i64axes: Vec<PlinkoAxisTranche>Trait Implementations
Sourceimpl Clone for PlinkoTranche
impl Clone for PlinkoTranche
Sourcefn clone(&self) -> PlinkoTranche
fn clone(&self) -> PlinkoTranche
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlinkoTranche
impl Debug for PlinkoTranche
Sourceimpl<'de> Deserialize<'de> for PlinkoTranche
impl<'de> Deserialize<'de> for PlinkoTranche
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlinkoTranche
impl JsonSchema for PlinkoTranche
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for PlinkoTranche
impl Serialize for PlinkoTranche
Sourceimpl Tsify for PlinkoTranche
impl Tsify for PlinkoTranche
const DECL: &'static str = "/**\n * \u{412}\u{441}\u{435} \u{43e}\u{441}\u{438} \u{43e}\u{434}\u{43d}\u{43e}\u{433}\u{43e} \u{443}\u{440}\u{43e}\u{432}\u{43d}\u{44f} \u{441}\u{443}\u{43d}\u{434}\u{443}\u{43a}\u{430}.\n */\nexport interface PlinkoTranche {\n chest_level: number;\n axes: PlinkoAxisTranche[];\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>